@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,7 +69,6 @@ import com.openexchange.oauth.OAuthAccountInvalidationListener;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.secret.SecretService;
-import com.openexchange.secret.osgi.tools.WhiteboardSecretService;
 import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.user.UserService;
@@ -81,8 +80,6 @@ import com.openexchange.user.UserService;
  */
 public final class FacebookMessagingActivator extends HousekeepingActivator {
 
-    private WhiteboardSecretService secretService;
-
     /**
      * Initializes a new {@link FacebookMessagingActivator}.
      */
@@ -93,7 +90,8 @@ public final class FacebookMessagingActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
-            ConfigurationService.class, ContextService.class, UserService.class, SessiondService.class, HtmlService.class, OAuthService.class, SecretService.class};
+            ConfigurationService.class, ContextService.class, UserService.class, SessiondService.class, HtmlService.class,
+            OAuthService.class, SecretService.class };
     }
 
     @Override
