@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,17 @@
 
 package com.openexchange.messaging.twitter;
 
+import java.util.Collections;
+import java.util.List;
 import java.util.Map;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.messaging.MessagingAccount;
 import com.openexchange.messaging.MessagingService;
 import com.openexchange.messaging.generic.DefaultMessagingAccountManager;
+import com.openexchange.messaging.twitter.osgi.Services;
+import com.openexchange.secret.SecretService;
+import com.openexchange.session.Session;
 
 
 /**
@@ -71,6 +77,17 @@ public final class TwitterMessagingAccountManager extends DefaultMessagingAccoun
         super(service);
     }
 
+    @Override
+    public List<MessagingAccount> getAccounts(Session session) throws OXException {
+        SecretService secretService = Services.optService(SecretService.class);
+        if (null != secretService && Strings.isEmpty(secretService.getSecret(session))) {
+            // The OAuth-based file storage needs a valid secret string for operation
+            return Collections.emptyList();
+        }
+
+        return super.getAccounts(session);
+    }
+
     @Override
     protected MessagingAccount modifyIncoming(final MessagingAccount account) throws OXException {
         final Map<String, Object> configuration = account.getConfiguration();
