@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,11 @@
 
 package com.openexchange.rss.preprocessors;
 
+import com.openexchange.rss.RssResult;
+
 /**
  * {@link AbstractPreprocessor} - The abstract pre-processor for RSS payload.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public abstract class AbstractPreprocessor implements RssPreprocessor {
@@ -59,10 +61,10 @@ public abstract class AbstractPreprocessor implements RssPreprocessor {
     private RssPreprocessor nextProcessor;
 
     @Override
-    public String process(final String payload) {
-        String retval = innerProcess(payload);
+    public String process(final String payload, RssResult rssResult) {
+        String retval = innerProcess(payload, rssResult);
         if (nextProcessor != null) {
-            retval = nextProcessor.process(retval);
+            retval = nextProcessor.process(retval, rssResult);
         }
         return retval;
     }
@@ -76,6 +78,6 @@ public abstract class AbstractPreprocessor implements RssPreprocessor {
     /**
      * Processes given payload.
      */
-    protected abstract String innerProcess(String payload);
+    protected abstract String innerProcess(String payload, RssResult rssResult);
 
 }
